summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-12-20 17:13:03 +0000
committerjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-12-20 17:13:03 +0000
commit58f5d567f2b2e8d8600c7bfc4206dd78b6b831ea (patch)
treefea5b4a81480011178891861998e13eade94bc8b
parent168389f9cd2eefad65b925d2b57731b760d8aade (diff)
downloadchromium_src-58f5d567f2b2e8d8600c7bfc4206dd78b6b831ea.zip
chromium_src-58f5d567f2b2e8d8600c7bfc4206dd78b6b831ea.tar.gz
chromium_src-58f5d567f2b2e8d8600c7bfc4206dd78b6b831ea.tar.bz2
Rename content::WebPage to content::WebContents
BUG=98716,105875 Review URL: http://codereview.chromium.org/9004010 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@115141 0039d316-1c4b-4281-b951-d872f2087c98
-rw-r--r--content/browser/tab_contents/tab_contents.h6
-rw-r--r--content/content_browser.gypi2
-rw-r--r--content/public/browser/web_contents.h (renamed from content/public/browser/web_page.h)10
3 files changed, 9 insertions, 9 deletions
diff --git a/content/browser/tab_contents/tab_contents.h b/content/browser/tab_contents/tab_contents.h
index 872d1d1..7324e95 100644
--- a/content/browser/tab_contents/tab_contents.h
+++ b/content/browser/tab_contents/tab_contents.h
@@ -27,7 +27,7 @@
#include "content/browser/tab_contents/tab_contents_observer.h"
#include "content/browser/webui/web_ui.h"
#include "content/common/content_export.h"
-#include "content/public/browser/web_page.h"
+#include "content/public/browser/web_contents.h"
#include "content/public/common/renderer_preferences.h"
#include "net/base/load_states.h"
#include "ui/gfx/native_widget_types.h"
@@ -54,7 +54,7 @@ namespace webkit_glue {
struct WebIntentData;
}
-class CONTENT_EXPORT TabContents : public content::WebPage,
+class CONTENT_EXPORT TabContents : public content::WebContents,
public PageNavigator,
public RenderViewHostDelegate,
public RenderViewHostManager::Delegate,
@@ -473,7 +473,7 @@ class CONTENT_EXPORT TabContents : public content::WebPage,
return java_bridge_dispatcher_host_manager_.get();
}
- // content::WebPage ----------------------------------------------------------
+ // content::WebContents ------------------------------------------------------
virtual const base::PropertyBag* GetPropertyBag() const OVERRIDE;
virtual base::PropertyBag* GetPropertyBag() OVERRIDE;
virtual TabContentsDelegate* GetDelegate() OVERRIDE;
diff --git a/content/content_browser.gypi b/content/content_browser.gypi
index 00be4f2..2a4d924 100644
--- a/content/content_browser.gypi
+++ b/content/content_browser.gypi
@@ -66,7 +66,7 @@
'public/browser/sensors.h',
'public/browser/sensors_listener.h',
'public/browser/user_metrics.h',
- 'public/browser/web_page.h',
+ 'public/browser/web_contents.h',
'browser/accessibility/browser_accessibility.cc',
'browser/accessibility/browser_accessibility.h',
'browser/accessibility/browser_accessibility_cocoa.h',
diff --git a/content/public/browser/web_page.h b/content/public/browser/web_contents.h
index d6dcbf6..55c1e07 100644
--- a/content/public/browser/web_page.h
+++ b/content/public/browser/web_contents.h
@@ -2,15 +2,15 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_PUBLIC_BROWSER_WEB_PAGE_H_
-#define CONTENT_PUBLIC_BROWSER_WEB_PAGE_H_
+#ifndef CONTENT_PUBLIC_BROWSER_WEB_CONTENTS_H_
+#define CONTENT_PUBLIC_BROWSER_WEB_CONTENTS_H_
#pragma once
#include "base/string16.h"
#include "content/common/content_export.h"
// TODO(jam): of course we will have to rename TabContentsDelgate,
// TabContentsView etc to use WebPage.
class TabContentsDelegate;
namespace base {
@@ -20,7 +20,7 @@ class PropertyBag;
namespace content {
// Describes what goes in the main content area of a tab.
-class WebPage {
+class WebContents {
public:
// Intrinsic tab state -------------------------------------------------------
@@ -38,4 +38,4 @@ class WebPage {
} // namespace content
-#endif // CONTENT_PUBLIC_BROWSER_WEB_PAGE_H_
+#endif // CONTENT_PUBLIC_BROWSER_WEB_CONTENTS_H_
@@ -2,15 +2,15 @@
#include "content/common/content_export.h"
// TODO(jam): of course we will have to rename TabContentsDelgate,
-// TabContentsView etc to use WebPage.
+// TabContentsView etc to use WebContents.
class TabContentsDelegate;
namespace base {